@@ -133,7 +133,21 @@ class StringParameter(
         :param tier: The tier of the string parameter. Default: - undefined
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameter.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                parameter_name: builtins.str,
+                region: builtins.str,
+                string_value: builtins.str,
+                allowed_pattern: typing.Optional[builtins.str] = None,
+                data_type: typing.Optional[aws_cdk.aws_ssm.ParameterDataType] = None,
+                description: typing.Optional[builtins.str] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                tier: typing.Optional[aws_cdk.aws_ssm.ParameterTier] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = StringParameterProps(
@@ -173,7 +187,18 @@ class StringParameter(
         :param simple_name: Indicates of the parameter name is a simple name (i.e. does not include "/" separators). This is only required only if ``parameterName`` is a token, which means we are unable to detect if the name is simple or "path-like" for the purpose of rendering SSM parameter ARNs. If ``parameterName`` is not specified, ``simpleName`` must be ``true`` (or undefined) since the name generated by AWS CloudFormation is always a simple name. Default: - auto-detect based on ``parameterName``
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameter.from_string_parameter_attributes)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                region: builtins.str,
+                type: typing.Optional[aws_cdk.aws_ssm.ParameterType] = None,
+                version: typing.Optional[jsii.Number] = None,
+                parameter_name: builtins.str,
+                simple_name: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         attrs = StringParameterAttributes(
@@ -203,7 +228,14 @@ class StringParameter(
         :param parameter_name: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameter.from_string_parameter_name)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                region: builtins.str,
+                parameter_name: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
@@ -228,7 +260,13 @@ class StringParameter(
         :param parameter_name: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameter.value_from_lookup)
+            def stub(
+                scope: constructs.Construct,
+                region: builtins.str,
+                parameter_name: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
@@ -241,7 +279,9 @@ class StringParameter(
         :param grantee: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameter.grant_read)
+            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
@@ -252,7 +292,9 @@ class StringParameter(
         :param grantee: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameter.grant_write)
+            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantWrite", [grantee]))
 
@@ -318,7 +360,16 @@ class StringParameterAttributes(aws_cdk.aws_ssm.StringParameterAttributes):
         :param region: The region to retrieve the parameter from. See AWS.SSM.region for more information.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameterAttributes.__init__)
+            def stub(
+                *,
+                parameter_name: builtins.str,
+                simple_name: typing.Optional[builtins.bool] = None,
+                type: typing.Optional[aws_cdk.aws_ssm.ParameterType] = None,
+                version: typing.Optional[jsii.Number] = None,
+                region: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
             check_type(argname="argument simple_name", value=simple_name, expected_type=type_hints["simple_name"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
@@ -442,7 +493,19 @@ class StringParameterProps:
         :param tier: The tier of the string parameter. Default: - undefined
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StringParameterProps.__init__)
+            def stub(
+                *,
+                parameter_name: builtins.str,
+                region: builtins.str,
+                string_value: builtins.str,
+                allowed_pattern: typing.Optional[builtins.str] = None,
+                data_type: typing.Optional[aws_cdk.aws_ssm.ParameterDataType] = None,
+                description: typing.Optional[builtins.str] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                tier: typing.Optional[aws_cdk.aws_ssm.ParameterTier] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument string_value", value=string_value, expected_type=type_hints["string_value"])
